==> 0.0.50.tar.gz: lib/SettingScreenComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:bui_component/Constants/AppColors.dart';

import 'Constants/SvgPictures.dart';
import 'Constants/ImageAssets.dart';

// ignore: must_be_immutable
class SettingScreenComponent extends StatefulWidget {
  final Function() onMenuPressed;
  final Function() onNotificationFunction;
  final Function() onSettingFunction;
  final Function() onMessageFunction;
  final Color backgroundColor;

  final Widget child;

  SettingScreenComponent({
    Key key,
    @required this.onMenuPressed,
    @required this.onNotificationFunction,
    @required this.onSettingFunction,
    @required this.onMessageFunction,
    @required this.backgroundColor,
    @required this.child,
  });

  @override
  _SettingScreenComponentState createState() => _SettingScreenComponentState();
}

class _SettingScreenComponentState extends State<SettingScreenComponent> {
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: AppColors.APP_COLOR_WHITE,
      body: SafeArea(
        child: Stack(
          children: [
            Container(
              height: 60,
              color: widget.backgroundColor != null
                  ? widget.backgroundColor
                  : AppColors.APP_COLOR_PRIMARY,
              child: Row(
                children: <Widget>[
                  ClipRRect(
                    borderRadius: BorderRadius.all(Radius.circular(32.0)),
                    child: InkWell(
                      splashColor: AppColors.errorWarning,
                      focusColor: AppColors.APP_COLOR_WHITE,
                      onTap: () {
                        widget.onMenuPressed();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(12.0),
                        child: Icon(
                          Icons.menu,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 130,
                  ),
                  ClipRRect(
                    borderRadius: BorderRadius.all(Radius.circular(32.0)),
                    child: InkWell(
                      splashColor: AppColors.errorWarning,
                      focusColor: AppColors.APP_COLOR_WHITE,
                      onTap: () {
                        widget.onNotificationFunction();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(12.0),
                        child: Icon(
                          Icons.notifications_active,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 10,
                  ),
                  ClipRRect(
                    borderRadius: BorderRadius.all(Radius.circular(32.0)),
                    child: InkWell(
                      splashColor: AppColors.errorWarning,
                      focusColor: AppColors.APP_COLOR_WHITE,
                      onTap: () {
                        widget.onSettingFunction();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(12.0),
                        child: Icon(
                          Icons.settings,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 10,
                  ),
                  ClipRRect(
                    borderRadius: BorderRadius.all(Radius.circular(32.0)),
                    child: InkWell(
                      splashColor: AppColors.errorWarning,
                      focusColor: AppColors.APP_COLOR_WHITE,
                      onTap: () {
                        widget.onMessageFunction();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(12.0),
                        child: Icon(
                          Icons.messenger_rounded,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            widget.child != null ? widget.child : Container(),
          ],
        ),
      ),
    );
  }
}

==> 0.0.63.tar.gz: lib/SettingScreenComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:flutter/material.dart';
import 'package:bui_component/Constants/AppColors.dart';


// ignore: must_be_immutable
class SettingScreenComponent extends StatefulWidget {
  final Function() onMenuPressed;
  final Function() onNotificationFunction;
  final Function() onSettingFunction;
  final Function() onMessageFunction;
  final Color backgroundColor;

  final Widget child;

  SettingScreenComponent({
    Key key,
     this.onMenuPressed,
     this.onNotificationFunction,
     this.onSettingFunction,
     this.onMessageFunction,
     this.backgroundColor,
     this.child,
  });

  @override
  _SettingScreenComponentState createState() => _SettingScreenComponentState();
}

class _SettingScreenComponentState extends State<SettingScreenComponent> {

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: AppColors.APP_COLOR_WHITE,
      body: SafeArea(
        child: Stack(
          children: [
            Container(
              height: 60,
              color: widget.backgroundColor != null
                  ? widget.backgroundColor
                  : AppColors.APP_COLOR_PRIMARY,
              child: Row(
                children: <Widget>[
                  ClipRRect(
                    borderRadius: BorderRadius.all(Radius.circular(32.0)),
                    child: InkWell(
                      splashColor: AppColors.errorWarning,
                      focusColor: AppColors.APP_COLOR_WHITE,
                      onTap: () {
                        widget.onMenuPressed();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(12.0),
                        child: Icon(
                          Icons.menu,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 130,
                  ),
                  ClipRRect(
                    borderRadius: BorderRadius.all(Radius.circular(32.0)),
                    child: InkWell(
                      splashColor: AppColors.errorWarning,
                      focusColor: AppColors.APP_COLOR_WHITE,
                      onTap: () {
                        widget.onNotificationFunction();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(12.0),
                        child: Icon(
                          Icons.notifications_active,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 10,
                  ),
                  ClipRRect(
                    borderRadius: BorderRadius.all(Radius.circular(32.0)),
                    child: InkWell(
                      splashColor: AppColors.errorWarning,
                      focusColor: AppColors.APP_COLOR_WHITE,
                      onTap: () {
                        widget.onSettingFunction();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(12.0),
                        child: Icon(
                          Icons.settings,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                  SizedBox(
                    width: 10,
                  ),
                  ClipRRect(
                    borderRadius: BorderRadius.all(Radius.circular(32.0)),
                    child: InkWell(
                      splashColor: AppColors.errorWarning,
                      focusColor: AppColors.APP_COLOR_WHITE,
                      onTap: () {
                        widget.onMessageFunction();
                      },
                      child: Padding(
                        padding: const EdgeInsets.all(12.0),
                        child: Icon(
                          Icons.messenger_rounded,
                          color: Colors.white,
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            widget.child != null ? widget.child : Container(),
          ],
        ),
      ),
    );
  }
}
